# Power User Tools

The Power User Tools is a collection of tools to make the life of, you guess it, a power user easier.
There are different areas of tools:

- ssh
- docker
- development (git...)

## Getting started

```bash
pip3 install power-user-tools
```

The Power User Tools will be installed to you computer to `/usr/local/bin`.

## Contributing

Contributions are welcome.
